IFNDEF D3D9_INC
D3D9_INC EQU <1>

IFNDEF DIRECT3D_VERSION
DIRECT3D_VERSION EQU 0900h
ENDIF ;DIRECT3D_VERSION

; This identifier is passed to Direct3DCreate9 in order to ensure that an
; application was built against the correct header files. This number is
; incremented whenever a header (or other) change would require applications
; to be rebuilt. If the version doesn't match, Direct3DCreate9 will fail.
; (The number itself has no meaning.)

IFDEF D3D_DEBUG_INFO
	D3D_SDK_VERSION EQU 80000020h
	D3D9b_SDK_VERSION EQU 8000001Fh
ELSE
	D3D_SDK_VERSION EQU 32
	D3D9b_SDK_VERSION EQU 31
ENDIF



include \masm32\gametesting\d3d9types.INC
;include \masm32\gametesting\d3d9caps.INC


; DLL Function for creating a Direct3D9 object. This object supports
; enumeration and allows the creation of Direct3DDevice9 objects.
; Pass the value of the constant D3D_SDK_VERSION to this function, so
; that the run-time can validate that your application was compiled
; against the right headers.

Direct3DCreate9 PROTO :DWORD
;IDirect3D9 * WINAPI Direct3DCreate9(UINT SDKVersion);

; Stubs for graphics profiling.

D3DPERF_BeginEvent PROTO :DWORD, :DWORD
;int WINAPI D3DPERF_BeginEvent( D3DCOLOR col, LPCWSTR wszName );

D3DPERF_EndEvent PROTO
;int WINAPI D3DPERF_EndEvent( void );

D3DPERF_GetStatus PROTO 
;DWORD WINAPI D3DPERF_GetStatus( void );

D3DPERF_QueryRepeatFrame PROTO 
;BOOL WINAPI D3DPERF_QueryRepeatFrame( void );

D3DPERF_SetMarker PROTO :DWORD, :DWORD
;void WINAPI D3DPERF_SetMarker( D3DCOLOR col, LPCWSTR wszName );

D3DPERF_SetOptions PROTO :DWORD
;void WINAPI D3DPERF_SetOptions( DWORD dwOptions );

D3DPERF_SetRegion PROTO :DWORD, :DWORD
;void WINAPI D3DPERF_SetRegion( D3DCOLOR col, LPCWSTR wszName );

; Direct3D interfaces




;****************************************************************************
;* Flags for SetPrivateData method on all D3D9 interfaces
;*
;* The passed adrptr is an IUnknown ptr. The SizeOfData argument to SetPrivateData
;* must be set to sizeof(IUnknown*). Direct3D will call AddRef through this
;* adrptr and Release when the private data is destroyed. The data will be
;* destroyed when another SetPrivateData with the same GUID is set, when
;* FreePrivateData is called, or when the D3D9 object is freed.
;****************************************************************************

D3DSPD_IUNKNOWN          EQU               00000001h

;****************************************************************************
;*
;* Flags for IDirect3D9::CreateDevice's BehaviorFlags
;*
;****************************************************************************

D3DCREATE_FPU_PRESERVE                 EQU  00000002h
D3DCREATE_MULTITHREADED                EQU  00000004h

D3DCREATE_PUREDEVICE                   EQU  00000010h
D3DCREATE_SOFTWARE_VERTEXPROCESSING    EQU  00000020h
D3DCREATE_HARDWARE_VERTEXPROCESSING    EQU  00000040h
D3DCREATE_MIXED_VERTEXPROCESSING       EQU  00000080h

D3DCREATE_DISABLE_DRIVER_MANAGEMENT    EQU  00000100h
D3DCREATE_ADAPTERGROUP_DEVICE          EQU  00000200h
D3DCREATE_DISABLE_DRIVER_MANAGEMENT_EX EQU  00000400h

; This flag causes the D3D runtime not to alter the focus 
; window in any way. Use with caution- the burden of supporting
; focus management events (alt-tab, etc.) falls on the 
; application, and appropriate responses (switching display
; mode, etc.) should be coded.

D3DCREATE_NOWINDOWCHANGES        EQU	00000800h


;****************************************************************************
;*
;* Parameter for IDirect3D9::CreateDevice's Adapter argument
;*
;****************************************************************************

D3DADAPTER_DEFAULT               EQU     0

;***************************************************************************
;*
;* Flags for IDirect3D9::EnumAdapters
;*
;****************************************************************************

D3DENUM_WHQL_LEVEL               EQU      00000002h

;****************************************************************************
;*
;* Maximum number of back-buffers supported in DX9
;*
;****************************************************************************

D3DPRESENT_BACK_BUFFERS_MAX      EQU       00000003h

;****************************************************************************
;*
;* Flags for IDirect3DDevice9::SetGammaRamp
;*
;****************************************************************************

D3DSGR_NO_CALIBRATION            EQU      00000000h
D3DSGR_CALIBRATE                 EQU      00000001h

;****************************************************************************
;*
;* Flags for IDirect3DDevice9::SetCursorPosition
;*
;****************************************************************************

D3DCURSOR_IMMEDIATE_UPDATE       EQU      00000001h

;****************************************************************************
;*
;* Flags for IDirect3DSwapChain9::Present
;*
;****************************************************************************/

D3DPRESENT_DONOTWAIT             EQU      00000001h
D3DPRESENT_LINEAR_CONTENT        EQU      00000002h

;****************************************************************************
;*
;* Flags for DrawPrimitive/DrawIndexedPrimitive
;*   Also valid for Begin/BeginIndexed
;*   Also valid for VertexBuffer::CreateVertexBuffer
;****************************************************************************



;*  DirectDraw error codes


_FACD3D  EQU 876

D3D_OK   EQU                            S_OK

D3DERR_WRONGTEXTUREFORMAT          EQU     2072
D3DERR_UNSUPPORTEDCOLOROPERATION   EQU     2073
D3DERR_UNSUPPORTEDCOLORARG         EQU     2074
D3DERR_UNSUPPORTEDALPHAOPERATION   EQU     2075
D3DERR_UNSUPPORTEDALPHAARG         EQU     2076
D3DERR_TOOMANYOPERATIONS           EQU     2077
D3DERR_CONFLICTINGTEXTUREFILTER    EQU     2078
D3DERR_UNSUPPORTEDFACTORVALUE      EQU     2079
D3DERR_CONFLICTINGRENDERSTATE      EQU     2081
D3DERR_UNSUPPORTEDTEXTUREFILTER    EQU     2082
D3DERR_CONFLICTINGTEXTUREPALETTE   EQU     2086
D3DERR_DRIVERINTERNALERROR         EQU     2087
D3DERR_NOTFOUND                    EQU     2150
D3DERR_MOREDATA                    EQU     2151
D3DERR_DEVICELOST                  EQU     2152
D3DERR_DEVICENOTRESET              EQU     2153
D3DERR_NOTAVAILABLE                EQU     2154
D3DERR_OUTOFVIDEOMEMORY            EQU     380
D3DERR_INVALIDDEVICE               EQU     2155
D3DERR_INVALIDCALL                 EQU     2156
D3DERR_DRIVERINVALIDCALL           EQU     2157
D3DERR_WASSTILLDRAWING             EQU     540
D3DOK_NOAUTOGEN                    EQU     2159

;    IFDEF D3D_DEBUG_INFO
;    D3DDEVICE_CREATION_PARAMETERS CreationParameters;
;    D3DPRESENT_PARAMETERS PresentParameters;
;    D3DDISPLAYMODE DisplayMode;
;    D3DCAPS9 Caps;
;    
;    UINT AvailableTextureMem;
;    UINT SwapChains;
;    UINT Textures;
;    UINT VertexBuffers;
;    UINT IndexBuffers;
;    UINT VertexShaders;
;    UINT PixelShaders;
;    
;    D3DVIEWPORT9 Viewport;
;    D3DMATRIX ProjectionMatrix;
;    D3DMATRIX ViewMatrix;
;    D3DMATRIX WorldMatrix;
;    D3DMATRIX TextureMatrices[8];
;    
;    DWORD FVF;
;    UINT VertexSize;
;    DWORD VertexShaderVersion;
;    DWORD PixelShaderVersion;
;    BOOL SoftwareVertexProcessing;
;    
;    D3DMATERIAL9 Material;
;    D3DLIGHT9 Lights[16];
;    BOOL LightsEnabled[16];
;    
;    D3DGAMMARAMP GammaRamp;
;    RECT ScissorRect;
;    BOOL DialogBoxMode;
;    
;    LPCWSTR EQU PTR DIRECT3D_VERSION
;    LPCWSTR CreationCallStack;
;    D3DPRESENT_PARAMETERS PresentParameters;
;    D3DDISPLAYMODE DisplayMode;
;    LPCWSTR CreationCallStack;
;    LPCWSTR CreationCallStack;
;    DWORD Version;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Width;
;    UINT Height;
;    UINT Levels;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    DWORD Priority;
;    DWORD LOD;
;    D3DTEXTUREFILTERTYPE FilterType;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Width;
;    UINT Height;
;    UINT Depth;
;    UINT Levels;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    DWORD Priority;
;    DWORD LOD;
;    D3DTEXTUREFILTERTYPE FilterType;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Width;
;    UINT Height;
;    UINT Levels;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    DWORD Priority;
;    DWORD LOD;
;    D3DTEXTUREFILTERTYPE FilterType;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Length;
;    DWORD Usage;
;    DWORD FVF;
;    D3DPOOL Pool;
;    DWORD Priority;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Length;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    DWORD Priority;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Width;
;    UINT Height;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    D3DMULTISAMPLE_TYPE MultiSampleType;
;    DWORD MultiSampleQuality;
;    DWORD Priority;
;    UINT LockCount;
;    UINT DCCount;
;    LPCWSTR CreationCallStack;
;    LPCWSTR Name;
;    UINT Width;
;    UINT Height;
;    UINT Depth;
;    DWORD Usage;
;    D3DFORMAT Format;
;    D3DPOOL Pool;
;    UINT LockCount;
;    LPCWSTR CreationCallStack;
;    D3DQUERYTYPE Type;
;    DWORD DataSize;
;    LPCWSTR CreationCallStack;

ELSE
echo -----------------------------------------
echo WARNING Duplicate include file D3D9.inc
echo -----------------------------------------
ENDIF

